<?php
namespace Eleddon\Admin\Classes;
/**
 * Eleddon Admin Template
 *
 * @package     Eleddon
 * @author      Codingeek
 * @copyright   2019 Codingeek
 * @license     GPL-2.0-or-later
 *
 *
 */


if( !defined( 'WPINC' ) ) {
    die;
}

if( !class_exists('Admin_Template') ) {

    class Admin_Template {

        private static $instance = null;

        private static $tabLists = [];

        function __construct() {

            self::tab_lists();
            self::template_content_area();

        }

        public static function getInstance() {

            if( self::$instance == null ) {
                self::$instance = new self();
            }

            return self::$instance;

        }


        /**
         * Admin Template Content Area
         *
         *
         */
    	private static function template_content_area() {
    		?>
        	<div class="eleddon_body-wrapper">
                <div class="eleddon_header-area"></div>
                <div class="eleddon_tabs-1 eleddon_tab-style-1">
                    <form id="eleddon_settings_from" action="" method="post">
                        <?php
                        // check if the user have submitted the settings
                        if ( isset( $_GET['settings-updated'] ) ) {
                        // add settings saved message with the class of "updated"
                        add_settings_error( 'eleddon_messages', 'eleddon_message', __( 'Settings Saved', 'eleddon' ), 'updated' );
                        }
                        //
                        settings_fields( 'eleddon_settings_option_group' ); 
                        //
                        do_settings_sections( 'eleddon_settings_option_group' ); 

                        // show error/update messages
                        settings_errors( 'eleddon_messages' );

                        // Admin Tab
                        self::admin_tab();
                        // General Section
                        self::section_general();
                        // Element Section
                        self::section_element(); 
                        // Go Pro Section
                        self::section_gopro();
                        ?>
                    </form>
                </div>
            </div>
    		<?php
    	}

        /**
         * Save Button
         *
         *
         */
        private static function save_button() {
            ?>
            <div class="eleddon_btn-wrapper">
                <button type="submit" class="eleddon_boxed-btn"><?php esc_html_e( 'Save Changes', 'eleddon' ); ?></button>
            </div>
            <?php
        }

        /**
         * Tab
         *
         *
         */
        private static function tab_lists() {

            self::$tabLists = [

                [
                    'name' => esc_html__( 'General', 'eleddon' ),
                    'icon' => 'flaticon-home',
                    'section_id' => '#eleddon_tabs_general',
                    'li_class' => 'is-active',
                    'type_for'   => 'ALL'
                ],
                [
                    'name' => esc_html__( 'Element', 'eleddon' ),
                    'icon' => 'flaticon-cubes-in-stack-with-shadow',
                    'section_id' => '#eleddon_tabs_elements',
                    'li_class' => '',
                    'type_for'   => 'ALL'
                ],
                [
                    'name'       => esc_html__( 'Extension', 'eleddon' ),
                    'icon'       => 'flaticon-puzzle-piece-plugin',
                    'section_id' => '#eleddon_tabs_extension',
                    'li_class'   => '',
                    'type_for'   => 'PRO'
                ],
                [
                    'name' => esc_html__( 'User Data', 'eleddon' ),
                    'icon' => 'flaticon-multiple-users-silhouette',
                    'section_id' => '#eleddon_tabs_user_data',
                    'li_class' => '',
                    'type_for'   => 'PRO'
                ],
                [
                    'name' => esc_html__( 'Go Premium', 'eleddon' ),
                    'icon' => 'flaticon-premium',
                    'section_id' => '#eleddon_tabs_gopro',
                    'li_class' => '',
                    'type_for'   => 'LITE'
                ]

            ];

            return self::$tabLists;

        }

        /**
         * Admin Template Tab
         *
         *
         */
        private static function admin_tab() {

            ?>
            <nav class="eleddon_tabs">
                <ul>
                <?php 
                if( !empty( self::$tabLists ) ) {
                    foreach( self::$tabLists as $tab ) {

                        if( ELEDDON_VERSION_TYPE == $tab['type_for'] || $tab['type_for'] == 'ALL'  ){

                            $class = !empty( $tab['li_class'] ) ? $tab['li_class'] : '';

                            echo '<li '.apply_filters( 'eleddon_tab_class', $class ).'  ><a href="'.esc_attr( $tab['section_id'] ).'"><i class="'.esc_attr( $tab['icon'] ).'"></i> '.esc_html( $tab['name'] ).'</a></li>';
                        }

                    }
                }
                ?>
                </ul>
            </nav>
            <?php
        }

        /**
         * General Section
         *
         *
         */
        private static function section_general() {
            $general = new General_Section();
            ?>
            <section class="tab-content  is-active " id="eleddon_tabs_general">
                <div class="eleddon_tab-content-inner clearfix">
                    <div class="eleddon_tab-content-head clearfix">

                        <div class="eleddon_tab-content-left eleddon_menu-1 eleddon_float-left">
                            <ul>
                                <li>
                                    <h3 class="eleddon_title-1"><?php echo esc_html( $general->sectionTitle ); ?></h3>
                                </li>
                            </ul>
                        </div>
                    </div>

                    <div class="eleddon-tab-content-body">
                        <div class="eleddon_row">
                            <div class="eleddon_col-7">
                                <div class="eleddon_row">
                                    <?php 
                                    $cardinfo = $general->general_card_info();

                                    if( !empty( $cardinfo ) ):
                                        foreach( $cardinfo as $info ):

                                    ?>
                                    <div class="eleddon_col-6">
                                        <!-- eleddon_feature-item -->
                                        <div class="eleddon_feature-item">
                                            <div class="eleddon_feature-icon-title clearfix">
                                                <?php
                                                if( !empty( $info['image'] ) ):
                                                ?>
                                                <div class="eleddon_feature-icon">
                                                    <img src="<?php echo esc_url( $info['image'] ); ?>" alt="card icon">
                                                </div>
                                                <?php 
                                                endif;
                                                //
                                                if( !empty( $info['title'] ) ):
                                                ?>
                                                <div class="eleddon_feature-title">
                                                    <h5><?php echo esc_html( $info['title'] ); ?></h5>
                                                </div>
                                                <?php 
                                                endif;
                                                ?>
                                            </div>
                                            <div class="eleddon_feature-brief">
                                                <?php
                                                //
                                                if( !empty( $info['description'] ) ) {
                                                    echo '<p>'.esc_html( $info['description'] ).'</p>';
                                                }
                                                //
                                                if( !empty( $info['link_text'] ) || !empty( $info['link_url'] ) ) {
                                                    echo '<div class="eleddon_btn-1"><a href="'.esc_url( $info['link_url'] ).'">'.esc_html( $info['link_text'] ).' <i class="fa fa-long-arrow-right"></i></a></div>';
                                                }   
                                                ?>
                                            </div>
                                        </div>
                                    </div>
                                    <?php 
                                        endforeach;
                                    endif;
                                    ?>
                                </div>
                            </div>

                            <div class="eleddon_col-5">
                            <?php 
                            $banner = $general->general_banner();

                            if( !empty( $banner ) ):
                                foreach( $banner as $val ):

                                    $bgImg = !empty( $val['bg_image'] ) ? $val['bg_image'] : '';
                            ?>
                                <div class="eleddon_banner-item eleddon_bg-image eleddon_color-white eleddon_text-center" data-bg="<?php echo esc_url( $bgImg ); ?>">
                                    <?php 
                                    if( !empty( $val['logo'] ) ):
                                    ?>
                                    <div class="eleddon_banner-logo">
                                        <img src="<?php echo esc_url( $val['logo'] ); ?>" alt="<?php esc_attr__( 'plugin logo', 'eleddon' ); ?>">
                                    </div>
                                    <?php 
                                    endif;
                                    ?>
                                    <div class="eleddon_banner-info">
                                        <?php
                                        // Title 
                                        if( !empty( $val['title'] ) ) {
                                            echo '<h2>'.esc_html( $val['title'] ).'</h2>';
                                        }
                                        // Short description
                                        if( !empty( $val['description'] ) ) {
                                            echo '<h4>'.esc_html( $val['description'] ).'</h4>';
                                        }
                                        //
                                        if( !empty( $val['link_text'] ) &&  !empty( $val['link_url'] ) ):
                                        ?>
                                        <div class="eleddon_btn-wrapper">
                                            <a class="eleddon_boxed-btn eleddon_round-btn eleddon_white-btn eleddon_button-1" href="<?php echo esc_url( $val['link_url'] ); ?>"><?php echo esc_html( $val['link_text'] ); ?> <i class="fa fa-long-arrow-right"></i></a>
                                        </div>
                                        <?php 
                                        endif;
                                        ?>
                                    </div>
                                </div>
                            <?php 
                                endforeach;
                            endif;
                            ?>

                            </div>

                        </div>
                    </div>

                </div>
            </section>
            <?php
        }

        /**
         * Section Element
         *
         *
         */
        private static function section_element() {

            $Elements = new Elements_Section();

            $getElements = $Elements->widget_lists();

            ?>
            <section class="tab-content" id="eleddon_tabs_elements">
                <div class="eleddon_tab-content-inner portfolio-area clearfix">
                    <div class="eleddon_tab-content-head clearfix">
                        <div class="eleddon_tab-content-left eleddon_menu-1 eleddon_float-left">
                            <ul>
                                <?php 
                                if( !empty( $Elements->sectionTitle ) ) {
                                    echo '<li><h3 class="eleddon_title-1">'.esc_html( $Elements->sectionTitle ).'</h3></li>';
                                }
                                //
                                if( ELEDDON_VERSION_TYPE == 'LITE' ):
                                ?>
                                <li>
                                    <!-- eleddon_plugin-option-menu -->
                                    <div class="eleddon_plugin-option-menu">
                                        <span data-filter="*" class="active"><?php esc_html_e( 'All', 'eleddon' ); ?></span>
                                        <span class="eleddon_lite" data-filter=".lite-item"><?php esc_html_e( 'Free', 'eleddon' ); ?></span>
                                        <span class="eleddon_pro" data-filter=".pro-item"><?php esc_html_e( 'Pro', 'eleddon' ); ?></span>
                                    </div>
                                </li>
                                <?php 
                                endif;
                                ?>
                                <li>
                                    <!-- eleddon_plugin-enable-disable-menu -->
                                    <div class="eleddon_plugin-enable-disable-menu">
                                        <span data-btn="enable"><?php esc_html_e( 'Enable All', 'eleddon' ); ?></span>
                                        <span data-btn="disable"><?php esc_html_e( 'Disable All', 'eleddon' ); ?></span>
                                    </div>
                                </li>

                            </ul>
                        </div>

                        <div class="eleddon_tab-content-right eleddon_menu-1 eleddon_float-right">
                            <ul>
                                <li>
                                    <div class="eleddon_search-form">
                                        <div class="eleddon_search-form-inner">
                                            <input data-search type="text" placeholder="<?php esc_html_e( 'Search...', 'eleddon' ); ?>">
                                        </div>
                                    </div>
                                </li>
                                <li><?php self::save_button(); ?></li>
                            </ul>
                        </div>
                    </div>
 
                    <div class="eleddon-tab-content-body eleddon_plugin-option-area">
                        <div class=" eleddon_row grid">
                                <!-- <div class="eleddon_plugin-option-sizer col-1"></div> -->
                                
                                <?php 
                                $activation = get_option('eleddon_widgets_activation');

                                if( !empty( $getElements ) ):
                                    foreach( $getElements as $elements ):

                                        // 
                                        $elementName = $elements['name'];

                                        $disabled = $itemClass = ''; 
                                        $itemWrapperClass ='lite-item';
                                        $checked = '';

                                        if( !empty( $elements['is_pro'] ) && ELEDDON_VERSION_TYPE == 'LITE' ) {
                                            $disabled = "disabled";
                                            $itemWrapperClass = $itemClass = "pro-item";
                                            $checked = "";
                                        }

                                        //
                                        if( is_array( $activation ) ) {
                                            if( in_array( $elementName , $activation ) ) {
                                                $checked = "checked";
                                            } else {
                                                $checked = "";
                                            }
                                        }


                                ?>
                                <!-- eleddon_plugin-option-item -->
                                <div class="eleddon_plugin-option-item eleddon_col-3 mb-10 <?php echo esc_attr( $itemWrapperClass ); ?>" data-filter-item data-filter-name="<?php echo esc_html( strtolower($elements['label']) ) ?>">
                                    <div class="eleddon_plugin-option-item-inner <?php echo esc_attr( $itemClass ); ?>">
                                        <?php
                                        if( !empty( $elements['is_pro'] ) && ELEDDON_VERSION_TYPE == 'LITE' ) {
                                            echo '<span class="eleddon_plugin-badge">'.esc_html__( 'Pro', 'eleddon' ).'</span>';
                                        }
                                        ?>
                                        <ul class="">
                                            <?php 
                                            if( !empty( $elements['label'] ) ) {
                                                echo '<li><h6>'.esc_html( $elements['label'] ).'</h6></li>';
                                            }
                                            //
                                            if( !empty( $elements['demo_url'] ) ) {
                                                echo '<li><a target="_blank" href="'.esc_url( $elements['demo_url'] ).'"><i class="fa fa-desktop"></i></a></li>';
                                            }
                                            //
                                            if( !empty( $elements['doc_url'] ) ):
                                            ?>
                                            <li>
                                                <?php
                                                echo '<a href="'.esc_url( $elements['doc_url'] ).'" target="_blank"><i class="fa fa-question-circle-o"></i></a>';
                                                ?>
                                                <span class="eleddon_help-text" ><?php esc_html_e( 'Hello! How can I help You?', 'eleddon' ); ?></span>
                                            </li>
                                            <?php
                                            endif;
                                            ?>
                                        </ul>
                                        <ul class="eleddon_float-right">
                                            <li>
                                                <div class="onoffswitch">
                                                    <input <?php echo esc_attr( $disabled.' '.$checked ); ?> type="checkbox" name="eleddon_widgets[]" class="onoffswitch-checkbox" id="<?php echo esc_attr( $elementName ); ?>" value="<?php echo esc_attr( $elementName ); ?>" >
                                                    <label class="onoffswitch-label" for="<?php echo esc_attr( $elementName ); ?>">
                                                        <span class="onoffswitch-inner"></span>
                                                        <span class="onoffswitch-switch"></span>
                                                    </label>
                                                </div>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                                <?php 
                                    endforeach;
                                endif;
                                ?>
                            
                        </div>
                    </div>
                </div>
            </section>
            <?php
        }

        private static function section_gopro() {

            $gopro = new Gopro_Section();

            ?>
            <section class="tab-content" id="eleddon_tabs_gopro">
                <div class="eleddon_tab-content-inner clearfix">

                    <div class="eleddon_tab-content-head clearfix">
                        <div class="eleddon_tab-content-left eleddon_menu-1 eleddon_float-left">
                            <ul>
                                <li>
                                    <h3 class="eleddon_title-1"><?php echo esc_html( $gopro->sectionTitle ); ?></h3>
                                </li>
                            </ul>
                        </div>
                    </div>

                    <div class="eleddon-tab-content-body">
                        <div class="eleddon_row">
                            <?php 
                            $cardinfo = $gopro->gopro_card_info();

                            if( !empty( $cardinfo ) ):
                                foreach( $cardinfo as $info ):

                            ?>
                            <div class="eleddon_col-6">
                                <!-- eleddon_feature-item -->
                                <div class="eleddon_feature-item">
                                    <div class="eleddon_feature-icon-title clearfix">
                                        <?php 
                                        if( !empty( $info['image'] ) ):
                                        ?>
                                        <div class="eleddon_feature-icon">
                                            <img src="<?php echo esc_url( $info['image'] ); ?>" alt="<?php echo esc_attr__( 'icon', 'eleddon' ) ?>">
                                        </div>
                                        <?php 
                                        endif;
                                        //
                                        if( !empty( $info['title'] ) ):
                                        ?>
                                        <div class="eleddon_feature-title">
                                            <h5><?php echo esc_html( $info['title'] ); ?></h5>
                                        </div>
                                        <?php 
                                        endif;
                                        ?>
                                    </div>
                                    
                                    <div class="eleddon_feature-brief">
                                        <?php
                                        if( !empty( $info['description'] ) ) {
                                            echo esc_html( $info['description'] );
                                        }
                                        //
                                        if( !empty( $info['link_text'] ) && !empty( $info['link_url'] ) ):
                                        ?>
                                        <div class="eleddon_btn-1"><a href="<?php echo esc_url( $info['link_url'] ); ?>"><?php echo esc_html( $info['link_text'] ); ?> <i class="fa fa-long-arrow-right"></i></a></div>
                                        <?php 
                                        endif;
                                        ?>
                                    </div>
                                    
                                </div>
                            </div>
                            <?php 
                                endforeach;
                            endif;
                            ?>
                        </div>
                    </div>

                </div>
            </section>
            <?php
        }


    }

}