<?php
namespace Eleddon;
/**
 * Eleddon
 *
 * @package     Eleddon
 * @author      Codingeek
 * @copyright   2019 Codingeek
 * @license     GPL-2.0-or-later
 *
 * @wordpress-plugin
 * Plugin Name: Eleddon lite
 * Plugin URI:  https://codingeek.net/eleddon
 * Description: Description of the plugin.
 * Version:     1.0.0
 * Author:      Codingeek
 * Author URI:  https://codingeek.net/
 * Text Domain: eleddon
 * License:     GPL v2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 *
 */


if( !defined( 'WPINC' ) ) {
    die;
}


/**
 * Define Plugin Dir Path Url constant
 * @since 1.0
 *
 */


// Plugin version
define( 'ELEDDON_VERSION', '1.0' );

// Plugin Type ( LITE, PRO )
define( 'ELEDDON_VERSION_TYPE', 'LITE' );

// Plugin option nane
define( 'ELEDDON_OPTION_NAME', 'eleddon_widgets_activation' );

// Plugin base dir path
if( !defined('ELEDDON_DIR_PATH') ) {
	define('ELEDDON_DIR_PATH', plugin_dir_path( __FILE__ ) );
}


// Admin dir path
if( !defined('ELEDDON_DIR_ADMIN') ) {
	define('ELEDDON_DIR_ADMIN', trailingslashit( ELEDDON_DIR_PATH. 'admin' ) );
}

// Inc dir path
if( !defined('ELEDDON_DIR_INC') ) {
	define('ELEDDON_DIR_INC', trailingslashit( ELEDDON_DIR_PATH. 'inc' ) );
}
// Widgets dir path
if( !defined('ELEDDON_DIR_WIDGETS') ) {
	define('ELEDDON_DIR_WIDGETS', trailingslashit( ELEDDON_DIR_PATH. 'widgets' ) );
}

// Plugin base dir url
if( !defined('ELEDDON_DIR_URL') ) {
	define('ELEDDON_DIR_URL', plugin_dir_url( __FILE__ ) );
}
// Plugin admin dir url
if( !defined('ELEDDON_ADMIN_URL') ) {
	define('ELEDDON_ADMIN_URL', trailingslashit( plugin_dir_url( __FILE__ ) . 'admin') );
}
// Plugin widgets assets dir url
if( !defined('ELEDDON_WIDGET_ASSETS_URL') ) {
	define('ELEDDON_WIDGET_ASSETS_URL', trailingslashit( plugin_dir_url( __FILE__ ) . 'widgets/assets') );
}


final class Eleddon{

    /**
     * Minimum Elementor Version
     *
     * Holds the minimum Elementor version required to run the plugin.
     *
     * @since 1.7.0
     * @since 1.7.1 Moved from property with that name to a constant.
     *
     * @var string Minimum Elementor version required to run the plugin.
     */
	const MINIMUM_ELEMENTOR_VERSION = '2.8.2';

    /**
     * Minimum PHP Version
     *
     * Holds the minimum PHP version required to run the plugin.
     *
     * @since 1.7.0
     * @since 1.7.1 Moved from property with that name to a constant.
     *
     * @var string Minimum PHP version required to run the plugin.
     */
	const MINIMUM_PHP_VERSION = '5.6';

    /**
     * Instance
     *
     * Holds a single instance of the `Eleddon` class.
     *
     * @since 1.0
     *
     * @access private
     * @static
     *
     * @var Eleddon A single instance of the class.
     */
    private static $instance = null;

	/**
	 * Class instance
	 *
	 *
	 * @since 1.0.0
	 * @access public
	 */

	public static function getInstance() {

		if( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}


	function __construct() {

		register_activation_hook( __FILE__, [$this, 'activation_hook'] );
		register_deactivation_hook( __FILE__, [$this, 'deactivation_hook'] );

		$this->init();

		
	}

	/**
	 * Initialize the plugin
	 *
	 *
	 * @since 1.0.0
	 * @access public
	 */

	public function init() {

		// Init include file
		$this->include_files();

	}

	/**
	 * Include require files
	 *
	 *
	 * @since 1.0.0
	 * @access public
	 */

	public function include_files() {

		require_once( ELEDDON_DIR_ADMIN.'admin.php' );
		require_once( ELEDDON_DIR_INC.'function.php' );
		require_once( ELEDDON_DIR_INC.'custom-controls/custom-control.php' );
		require_once( ELEDDON_DIR_INC.'classes/class-enqueue-base.php' );
		require_once( ELEDDON_DIR_INC.'classes/class-enqueue.php' );
		require_once( ELEDDON_DIR_WIDGETS.'class-widgets-list.php' );
		require_once( ELEDDON_DIR_WIDGETS.'class-widgets-base.php' );
		
	} 
	/**
	 * Plugin activation hook
	 *
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function activation_hook() {

		$widgets_list = \Eleddon\Widgets\Widgets_List::widgets_list_lite();

		$widgets_list = array_column( $widgets_list , 'name');

		add_option( ELEDDON_OPTION_NAME, $widgets_list );

	}

	/**
	 * Plugin deactivation hook
	 *
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function deactivation_hook() {
		delete_option( ELEDDON_OPTION_NAME );
	}

}

Eleddon::getInstance();