<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor Accordion widget.
 *
 * @since 1.0
 */
class Accordion extends Widget_Base {

	public function get_name() {
		return 'eleddon-accordion';
	}

	public function get_title() {
		return __( 'Accordion', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-accordion';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();


        // ----------------------------------------  Accordion content ------------------------------
        $this->start_controls_section(
            'eleddon_accordion_settings',
            [
                'label' => esc_html__( 'Accordion', 'eleddon' ),
            ]
        );

        $repeater->add_control(
            'accordion_title', [
                'label' => __( 'Title', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'List Title' , 'eleddon' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'accordion_desc', [
                'label' => __( 'Description', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => __( 'List Title' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'accordion',
            [
                'label' => __( 'Accordion', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'accordion_title' => __( '01. Frequently Asked Questions?', 'eleddon' ),
                        'accordion_desc' => __( 'Duis porta, ligula rhoncus euismod pretium, nisi tellus eleifend odio, luctus viverra sem dolor id sem', 'eleddon' ),
                    ],
                ],
                'title_field' => '{{{ accordion_title }}}',
            ]
        );


        $this->end_controls_section(); // End Accordion content

		//------------------------------ Accordion Style ------------------------------
		$this->start_controls_section(
			'eleddon_accordion_style', [
				'label' => esc_html__( 'Style', 'eleddon' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Title Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbandel-single-accordion .heading' => 'color: {{VALUE}}',
                ],
                'default'   => '#484848',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __( 'Title Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .tbandel-single-accordion .heading',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->add_control(
        'bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'eleddon' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .tbandel-single-accordion' => 'background-color: {{VALUE}};',
                ],
            ]
        );

		$this->end_controls_section();

        $this->start_controls_section(
            'eleddon_accordion_expand_style', [
                'label' => esc_html__( 'Style After Expand', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'expeand_title_color',
            [
                'label' => __( 'Title Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbandel-single-accordion.active .heading' => 'color: {{VALUE}}',
                ],
                'default'   => '#ff5a5f',
            ]
        );


        $this->add_control(
        'expeand_content_color',
            [
                'label'     => esc_html__( 'Content Color', 'eleddon' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#484848',
                'selectors' => [
                    '{{WRAPPER}} .tbandel-single-accordion.active .content' => 'color: {{VALUE}};',
                ],
            ]
        );

         $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' => __( 'Content Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .tbandel-single-accordion.active .content',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->add_control(
        'expeand_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'eleddon' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#fff7f8',
                'selectors' => [
                    '{{WRAPPER}} .tbandel-single-accordion.active' => 'background-color: {{VALUE}};',
                ],
            ]
        );


     $this->end_controls_section();


	}

	protected function render() {

        $settings = $this->get_settings();

        $style = $settings['accordion_style'] == 'style_2' ? 'red-bg' : '';

        ?>
        <div class="tbandel-accordion-wrapper <?php echo esc_attr( $style ); ?>">

            <?php
            if( !empty( $settings['accordion'] ) ):
                foreach( $settings['accordion'] as $accordion ):
            ?>
            <div class="tbandel-single-accordion">
                <?php 
                if( !empty( $accordion['accordion_title'] ) ){
                    echo '<a href="#" class="heading">'.esc_html( $accordion['accordion_title'] ).'</a>';
                }
                ?>
                <div class="content">
                    <?php
                    if( !empty( $accordion['accordion_desc'] ) ) {
                        echo '<p>'.esc_html( $accordion['accordion_desc'] ).'</p>';
                    }
                    ?>
                </div>
                <div class="expand-icon"></div>
            </div>
            <?php 
                endforeach;
            endif;
            ?>
        </div>
        <?php


    }
	
    public function get_script_depends() {
        return [ 'eleddon-main'];
    }


}
