<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor Card widget.
 *
 * @since 1.0
 */
class Card extends Widget_Base {

	public function get_name() {
		return 'eleddon-card';
	}

	public function get_title() {
		return __( 'Card', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-menu-card';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();

        $assetsUrl = ELEDDON_WIDGET_ASSETS_URL.'img/card/';

        // ----------------------------------------  Card content ------------------------------
        $this->start_controls_section(
            'eleddon_card_settings',
            [
                'label' => esc_html__( 'Card', 'eleddon' ),
            ]
        );
        $this->add_control(
            'card_style',
            [
                'label' => __( 'Select Style', 'eleddon' ),
                'type' => 'popup-select',
                'label_block' => false,
                'options' => [
                    'style-one' => [
                        'name' => esc_html__( 'Card 1', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'card1.png', 
                        'type' => 'free' 
                    ],
                    'style-two' => [
                        'name' => esc_html__( 'Card 2', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'card2.png', 
                        'type' => 'free' 
                    ],                    

                ]
            ]
        );

        $this->add_control(
            'name', [
                'label' => __( 'Card Name', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Hurawalhi Island' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'url', [
                'label' => esc_html__( 'Url', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'default'     => [
                        'url' => '#'
                    ],
            ]
        );

        $this->add_control(
            'card_img', [
                'label' => esc_html__( 'Card Image', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'country', [
                'label' => __( 'Country', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Australia' , 'eleddon' ),
                'label_block' => true,
            ]
        );         

        $this->add_control(
            'rating', [
                'label' => __( 'Rating', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( '4.5' , 'eleddon' ),
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'price_text', [
                'label' => __( 'Price Txt', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Low Price' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'price', [
                'label' => __( 'Price Txt', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( '$620' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'icon', [
                'label' => esc_html__( 'Icon', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::ICON,
                'label_block' => true,

            ]
        );        

        $repeater->add_control(
            'textone', [
                'label' => esc_html__( 'Text one', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,

            ]
        );        

        $repeater->add_control(
            'texttwo', [
                'label' => esc_html__( 'Text Two', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,

            ]
        );


        $this->add_control(
            'list',
            [
                'label' => __( 'Card Details', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'icon' => __( 'fa fa-clock', 'eleddon' ),
                        'textone' => __( 'Duration', 'eleddon' ),
                        'texttwo' => __( '4 days', 'eleddon' ),
                    ],                    
                    [
                        'icon' => __( 'fa fa-users', 'eleddon' ),
                        'textone' => __( 'Duration', 'eleddon' ),
                        'texttwo' => __( '4 days', 'eleddon' ),
                    ],
                     [
                        'icon' => __( 'fa fa-id-card', 'eleddon' ),
                        'textone' => __( 'Duration', 'eleddon' ),
                        'texttwo' => __( '4 days', 'eleddon' ),
                    ],

                ],
                'title_field' => '{{{ icon }}}',
                'condition' => [
                    'card_style' =>[ 'style-one' ],
                ],
            ]

        );

        $this->end_controls_section(); // End Card content


		//------------------------------ Title Style ------------------------------
		$this->start_controls_section(
			'eleddon_title_style', [
				'label' => esc_html__( 'Title Style', 'eleddon' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Title Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-card .title' => 'color: {{VALUE}}',
                ],
                'default'   => '#484848',
            ]
        );

        $this->add_control(
            'title_hover_color',
            [
                'label' => __( 'Title Hover Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-card .title:hover' => 'color: {{VALUE}}',
                ],
                'default'   => '#ff5a5f',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __( 'Title Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .eleddon-single-card .title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

		$this->end_controls_section();

     //------------------------------ country Style ------------------------------
        $this->start_controls_section(
            'eleddon_country_style', [
                'label' => esc_html__( 'Country Style', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'country_color',
            [
                'label' => __( 'Country Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-card .country' => 'color: {{VALUE}}',
                ],
                'default'   => '#767676',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'country_typography',
                'label' => __( 'Title Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .eleddon-single-card .country',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->end_controls_section();

        //------------------------------ card Style One------------------------------
        $this->start_controls_section(
            'eleddon_card_style_one', [
                'label' => esc_html__( 'Card One Style', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'card_style' =>[ 'style-one' ],
                ],
            ]
        );

        $this->add_control(
            'style_one_icon',
            [
                'label' => __( 'Icon Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-card .icon-box' => 'color: {{VALUE}}',
                ],
                'default'   => '#ff5a5f',
            ]
        );


        $this->add_control(
            'style_one_txt_color',
            [
                'label' => __( 'Text One Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-card .package-tag' => 'color: {{VALUE}}',
                ],
                'default'   => '#767676',
            ]
        );

         $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'style_one_txt_typo',
                'label' => __( 'Title Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .eleddon-single-card .package-tag',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->add_control(
            'style_two_txt_color',
            [
                'label' => __( 'Text Two Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} h4' => 'color: {{VALUE}}',
                ],
                'default'   => '#484848',
            ]
        );

         $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'style_two_txt_typo',
                'label' => __( 'Title Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} h4',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->end_controls_section();



        //------------------------------ card Style One------------------------------
        $this->start_controls_section(
            'eleddon_card_style_two', [
                'label' => esc_html__( 'Card Two Style', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'card_style' =>[ 'style-two' ],
                ],
            ]
        );


        $this->add_control(
            'style_two_price_txt',
            [
                'label' => __( 'Price Text Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .price-tag' => 'color: {{VALUE}}',
                ],
                'default'   => '#767676',
            ]
        );

         $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'style_two_price_type',
                'label' => __( 'Price Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .price-tag',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );    

         $this->add_control(
            'style_two_price',
            [
                'label' => __( 'Price Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .price-count' => 'color: {{VALUE}}',
                ],
                'default'   => '#484859',
            ]
        );

         $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'style_two_price',
                'label' => __( 'Price Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .price-count',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->end_controls_section();


	}

	protected function render() {

        $settings = $this->get_settings();
        if( $settings['card_style'] == 'style-one' ) {
        ?>
        <div class="eleddon-single-card style-01">
            <?php if( !empty( $settings['card_img']['url'] ) ) {
                $url = $settings['card_img']['url'];
              ?>
                <div class="card-cover">
                    <img src="<?php echo esc_url( $url ); ?>" alt="<?php echo esc_attr( eleddon_image_alt( $url ) ); ?>">
                </div>
            <?php } ?>
            <div class="card-content">
                <div class="title-box">
                    <a href="<?php echo esc_url( $settings['url']['url'] ); ?>" class="title"><?php echo esc_html( $settings['name'] ); ?></a>
                    <?php if( !empty( $settings['rating'] ) ) : ?>
                        <div class="rating">
                            <i class="fas fa-star"></i>
                            <p><?php echo esc_html( $settings['rating'] ); ?></p>
                        </div>
                    <?php endif; ?>
                </div>
                <p class="country"><?php echo esc_html( $settings['country'] ); ?></p>
                <div class="package-details-wrapper">
                    <?php foreach( $settings['list'] as $list ) : ?>
                        <div class="single-package-details">
                            <div class="icon-box">
                                <i class="<?php echo esc_attr( $list['icon'] ); ?>"></i>
                            </div>
                            <p class="package-tag"><?php echo esc_html( $list['textone'] ); ?></p>
                            <h4 class="package-quantity"><?php echo esc_html( $list['texttwo'] ); ?></h4>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        <?php }else{ ?>
           <div class="eleddon-single-card style-02">

                <?php if( !empty( $settings['card_img']['url'] ) ) {
                 $url = $settings['card_img']['url'];
                 ?>
                <div class="card-cover">
                    <img src="<?php echo esc_url( $url ); ?>" alt="<?php echo esc_attr( eleddon_image_alt( $url ) ); ?>">
                </div>
                <?php } ?>

                <div class="card-content">
                    <p class="country"><?php echo esc_html( $settings['country'] ); ?></p>
                    <div class="title-box">
                        <a href="<?php echo esc_url( $settings['url']['url'] ); ?>" class="title"><?php echo esc_html( $settings['name'] ); ?></a>
                    </div>
                    <div class="package-price-wrapper">
                        <div class="price">
                            <?php if( !empty( $settings['price_text'] ) ) : ?>
                            <p class="price-tag"><?php echo esc_html( $settings['price_text'] ); ?></p>
                            <?php endif; ?>
                            <h4 class="price-count"><?php echo esc_html( $settings['price'] ); ?></h4>
                        </div>
                        <a href="<?php echo esc_url( $settings['url'] ); ?>" class="like-btn"><i class="far fa-heart"></i></a>
                    </div>
                </div>
            </div>
        <?php }   

    }
	
    public function get_script_depends() {
        return [ 'eleddon-main'];
    }


}
