<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor Contact widget.
 *
 * @since 1.0
 */
class Contact extends Widget_Base {

	public function get_name() {
		return 'eleddon-Contact';
	}

	public function get_title() {
		return __( 'Contact', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-mail';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

     if (!function_exists('wpcf7')) {
        $this->start_controls_section(
            'eleddon_global_warning',
            [
                'label' => __('Warning!', 'eleddon'),
            ]
        );

        $this->add_control(
            'warning_text',
            [
                'type' => Controls_Manager::RAW_HTML,
                'raw' => __('<strong>Contact Form 7</strong> is not activated on your site. Please activate <strong>Contact Form 7</strong> first.', 'eleddon'),
                'content_classes' => 'eleddon-warining',
            ]
        );

        $this->end_controls_section();
    } else {

            // ----------------------------------------  Contact content ------------------------------
            $this->start_controls_section(
                'eleddon_Contact_settings',
                [
                    'label' => esc_html__( 'Contact', 'eleddon' ),
                ]
            );
            
             $this->add_control(
                'cf7_shortcode',[
                    'label' => 'Contact Form',
                    'type' => Controls_Manager::SELECT,
                    'options' => get_contact_form_7_posts(),
                ]
            );


            $this->end_controls_section(); // End Contact content


    		//------------------------------ Contact Style ------------------------------
    		$this->start_controls_section(
    			'eleddon_Contact_style', [
    				'label' => esc_html__( 'Style', 'eleddon' ),
    				'tab' => Controls_Manager::TAB_STYLE,
    			]
    		);

            $this->add_responsive_control(
            'field_width',
            [
                'label' => __( 'Width', 'eleddon' ),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'size_units' => [ '%', 'px' ],
                'range' => [
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .wpcf7-form-control:not(.wpcf7-submit)' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .ha-cf7-form label' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'bottom_margin',
            [
                'label' => __( 'Spacing Bottom', 'eleddon' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .wpcf7-form-control:not(.wpcf7-submit)' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typography',
                'label' => __( 'Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} label',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->add_control(
            'text_color',
            [
                'label' => __( 'Text Color', 'eleddon' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} label' => 'color: {{VALUE}}',
                ],
            ]
        );

    	$this->end_controls_section();

        }
	}

	protected function render() {

        $settings = $this->get_settings();

        $contact_form = !empty($settings['cf7_shortcode'])  ? $settings['cf7_shortcode'] : '';

        ?>

         <?php echo do_shortcode('[contact-form-7 id="' . $contact_form . '"]'); ?>

        <?php    

    }
	
    public function get_script_depends() {
        return [ 'eleddon-main'];
    }


}
