<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor Logo Carousel widget.
 *
 * @since 1.0
 */
class Logo_Carousel extends Widget_Base {

	public function get_name() {
		return 'eleddon-logo-carousel';
	}

	public function get_title() {
		return __( 'Logo Carousel', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-logo';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();

        $assetsUrl = ELEDDON_WIDGET_ASSETS_URL.'img/';

        // ----------------------------------------  Logo Carousel content ------------------------------
        $this->start_controls_section(
            'eleddon_logo_carousel_settings',
            [
                'label' => esc_html__( 'Logo Carousel', 'eleddon' ),
            ]
        );
        $this->add_control(
            'logo_carousel_style',
            [
                'label' => __( 'Select Style', 'eleddon' ),
                'type' => 'popup-select',
                'label_block' => false,
                'options' => [
                    'style-one' => [ 
                        'name' => esc_html__( 'Logo Carousel Style 1', 'eleddon' ), 
                        'cat' => 'Travel', 
                        'url' => $assetsUrl.'logo-caro-1.png', 
                        'type' => 'free' 
                    ],
                    'style-two' => [ 
                        'name' => esc_html__( 'Logo Carousel Style 2', 'eleddon' ), 
                        'cat' => 'Travel', 
                        'url' => $assetsUrl.'logo-caro-2.png', 
                        'type' => 'free' 
                    ]


                ]
            ]
        );

        $this->add_control(
            'logo_carousel',
            [
                'label' => __( 'Add Images', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::GALLERY,
                'default' => [],
            ]
        );

        $this->end_controls_section(); // End carousel content


		//------------------------------ Carousel settings ------------------------------

		$this->start_controls_section(
            'eleddon_logo_js_settings',
            [
                'label' => esc_html__( 'Settings', 'eleddon' ),
            ]
        );


        $this->add_control(
            'items',
            [
                'label' => esc_html__( 'items', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 5,
            ]
        );

        $this->add_control(
            'speed',
            [
                'label' => esc_html__( 'speed', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 500,
            ]
        );

		$this->end_controls_section();       

         //------------------------------ Carousel Style ------------------------------
        $this->start_controls_section(
            'eleddon_carousel_style', [
                'label' => esc_html__( 'Arrow Style', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

          $this->start_controls_tabs( '_tabs_arrow' );

        $this->start_controls_tab(
            'arrow_normal',
            [
                'label' => __( 'Normal', 'eleddon' ),
            ]
        );

        $this->add_control(
            'arrow_color',
            [
                'label' => __( 'Arrow Color', 'eleddon' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#ff5a5f',
                'selectors' => [
                    '{{WRAPPER}} .sponsor-carousel-wrapper .slick-arrow' => 'color: {{VALUE}};',
                ],
            ]
        );        

        $this->add_control(
            'bg_color',
            [
                'label' => __( 'Background Color', 'eleddon' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .sponsor-carousel-wrapper .slick-arrow' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'arrow_hover',
            [
                'label' => __( 'Hover', 'eleddon' ),
            ]
        );

        $this->add_control(
            'arrow_hover_color',
            [
                'label' => __( 'Arrow Hover Color', 'eleddon' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .sponsor-carousel-wrapper .slick-arrow:hover' => 'color: {{VALUE}};',
                ],
            ]
        );        

        $this->add_control(
            'bg_hover_color',
            [
                'label' => __( 'Hover Background Color', 'eleddon' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#ff5a5f',
                'selectors' => [
                    '{{WRAPPER}} .sponsor-carousel-wrapper .slick-arrow:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();


	}

	protected function render() {

        $settings = $this->get_settings();

        $dataOption = [ 'speed' => $settings['speed'],'items' => $settings['items'],  ];
        $dataOption = json_encode( $dataOption );

        ?>
        <div class="sponsor-carousel-wrapper <?php echo esc_attr( $settings['logo_carousel_style'] ); ?>" data-options="<?php echo esc_attr( $dataOption ); ?>">
            <?php 
            if( !empty( $settings ) ):
                foreach( $settings['logo_carousel'] as $logo_carousel ):
            ?>
            <div class="sponsor-carousel-item">
                <?php 
                echo '<img src="'.esc_url( $logo_carousel['url'] ).'" alt="'.esc_attr( eleddon_image_alt( $logo_carousel['url'] ) ).'" >';
                ?>
            </div>
            <?php 
                endforeach;
            endif;
            ?>
        </div>
        <?php

    }
	
    public function get_script_depends() {
        return [ 'eleddon-main', 'slick', 'fontawesome' ];
    }

    public function get_style_depends() {
        return [ 'slick', 'fontawesome'];
    }


}
