<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor Pricing widget.
 *
 * @since 1.0
 */
class Pricing extends Widget_Base {

	public function get_name() {
		return 'eleddon-pricing';
	}

	public function get_title() {
		return __( 'Pricing', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-price-table';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();

        $assetsUrl = ELEDDON_WIDGET_ASSETS_URL.'img/pricing/';

        // ----------------------------------------  Pricing content ------------------------------
        $this->start_controls_section(
            'eleddon_pricing_settings',
            [
                'label' => esc_html__( 'Pricing', 'eleddon' ),
            ]
        );

        $this->add_control(
            'name', [
                'label' => __( 'Pricing Name', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Tour One' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'price', [
                'label' => __( 'Price ', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( '$79.99' , 'eleddon' ),
                'label_block' => true,
            ]
        );        

        $this->add_control(
            'price_type', [
                'label' => __( 'Price Type', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'personal' , 'eleddon' ),
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'btn', [
                'label' => __( 'Price Button Text', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Book Now' , 'eleddon' ),
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'url', [
                'label' => esc_html__( 'Button Url', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'default'     => [
                        'url' => '#'
                    ],
            ]
        );


        $this->add_control(
            'pricing_img', [
                'label' => esc_html__( 'Pricing Image', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'features', [
                'label' => esc_html__( 'Features', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default'=> esc_html__( 'Lorem ipsum dolor sit amet', 'eleddon' )

            ]
        );

        $repeater->add_control(
            'availability',
            [
                'label' => __( 'Available ?', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Yes', 'eleddon' ),
                'label_off' => __( 'No', 'eleddon' ),
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'acitve',
            [
                'label' => __( 'Active Pricing ?', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Yes', 'eleddon' ),
                'label_off' => __( 'No', 'eleddon' ),
                'return_value' => 'centered',
            ]
        );


        $this->add_control(
            'list',
            [
                'label' => __( 'Pricing Details', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'features' => __( 'Lorem ipsum dolor sit amet', 'eleddon' ),
                        'availability' => __( '1', 'eleddon' ),
                    ],                     
                    [
                        'features' => __( 'Lorem ipsum dolor sit amet', 'eleddon' ),
                        'availability' => __( '1', 'eleddon' ),
                    ],                     
                    [
                        'features' => __( 'Lorem ipsum dolor sit amet', 'eleddon' ),
                        'availability' => __( '1', 'eleddon' ),
                    ],                    

                ],
                'title_field' => '{{{ features }}}',
            ]

        );

        $this->end_controls_section(); // End Pricing content


		//------------------------------ Pricing Style ------------------------------
		$this->start_controls_section(
			'eleddon_pricing_style', [
				'label' => esc_html__( 'Primary Color', 'eleddon' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'primary_color',
            [
                'label' => __( 'Primary Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-pricing .price-count' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-pricing.centered .booking-btn:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-pricing a.booking-btn' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-pricing .booking-btn' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-pricing .popular-tag' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-pricing.centered .booking-btn:hover' => 'color: {{VALUE}}',
                ],
                'default'   => '#FF5A5F',
            ]
        );        

        $this->add_control(
            'menu_hover_color',
            [
                'label' => __( 'Menu Hover Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-pricing a.booking-btn:hover' => 'color: {{VALUE}}',
                ],
                'default'   => '#fff',
            ]
        );    

        $this->add_control(
            'actove_price_menu_color',
            [
                'label' => __( 'Menu Hover Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-pricing.centered .booking-btn' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-pricing.centered .booking-btn:hover' => 'background:none}',
                ],
                'default'   => '#fff',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'primary_typography',
                'label' => __( 'Title Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .eleddon-single-card .country',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

		$this->end_controls_section();

        $this->start_controls_section(
            'eleddon_tile_style', [
                'label' => esc_html__( 'Content Style', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'price_name_color',
            [
                'label' => __( 'Price Title Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .pricing-title' => 'color: {{VALUE}}',
                ],
                'default'   => '#28375A',
            ]
        );

        $this->add_control(
            'price_content_color',
            [
                'label' => __( 'Price Content Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-pricing li' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-pricing .price-person' => 'color: {{VALUE}}',
                ],
                'default'   => '#767676',
            ]
        );

        $this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings();
       // if( $settings['pricing_style'] == 'style-one' ) {
        ?>
        <div class="eleddon-single-pricing <?php echo esc_attr( $settings['acitve'] ); ?>">
           <?php  if( ! empty( $settings['acitve'] ) ): ?>
                 <div class="popular-tag">most popular</div>
           <?php endif; ?>

            <?php if( !empty( $settings['pricing_img']['url'] ) ) :
                $image_url = $settings['pricing_img']['url'];
              ?>
                <img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( eleddon_image_alt( $url ) ); ?>" class="pricing-img">
            <?php endif; ?>
          <h3 class="pricing-title"><?php echo esc_html( $settings['name'] ); ?></h3>
          <h2 class="price-count"><?php echo esc_html( $settings['price'] ); ?></h2>
          <p class="price-person"><?php echo esc_html( $settings['price_type'] ); ?></p>
          <?php if( !empty( $settings['list'] ) ) : ?>
          <ul class="package-features">
             <?php 
                foreach( $settings['list'] as $list ) :
                $availability = ( $list['availability'] == 'yes' ? 'available' : 'not-available' );
              ?>
               <li class="<?php echo esc_attr( $availability ); ?>"><?php echo esc_html( $list['features'] ); ?></li>
             <?php endforeach; ?>
          </ul>
        <?php endif; ?>
          <a href="<?php echo esc_url( $settings['url']['url'] ); ?>" class="booking-btn"><?php echo esc_html( $settings['btn'] ); ?></a>
      </div>

        <?php //}   

    }
	
    public function get_script_depends() {
        return [ 'eleddon-main'];
    }


}
