<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor Progressbar widget.
 *
 * @since 1.0
 */
class Progressbar extends Widget_Base {

	public function get_name() {
		return 'eleddon-progressbar';
	}

	public function get_title() {
		return __( 'Progressbar', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-skill-bar';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();

        $assetsUrl = ELEDDON_WIDGET_ASSETS_URL.'img/progressbar/';

        // ----------------------------------------  Progressbar content ------------------------------
        $this->start_controls_section(
            'eleddon_progressbar_settings',
            [
                'label' => esc_html__( 'Progressbar', 'eleddon' ),
            ]
        );
        $this->add_control(
            'progressbar_style',
            [
                'label' => __( 'Select Style', 'eleddon' ),
                'type' => 'popup-select',
                'label_block' => false,
                'options' => [
                    'style-one' => [
                        'name' => esc_html__( 'Progressbar 1', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'progressbar2.png', 
                        'type' => 'free' 
                    ],
                    'style-two' => [
                        'name' => esc_html__( 'Progressbar 2', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'progressbar1.png', 
                        'type' => 'free' 
                    ],                    

                ]
            ]
        );

        $this->add_control(
            'percentage', [
                'label' => __( 'Progressbar Percentage', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( '80' , 'eleddon' ),
                'label_block' => true,
            ]
        ); 

        $this->add_control(
            'title', [
                'label' => __( 'Progressbar Title', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Ticket Booking' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'speed', [
                'label' => __( 'Progressbar Speed', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( '1200' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $this->end_controls_section(); // End Progressbar content


		//------------------------------ Progressbar Style ------------------------------
		$this->start_controls_section(
			'eleddon_progressbar_style', [
				'label' => esc_html__( 'Prigress Bar Style', 'eleddon' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Title Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-progressbar h4' => 'color: {{VALUE}}',
                ],
                'default'   => '#28375A',
            ]
        );

        $this->add_control(
            'bg_bar_color',
            [
                'label' => __( 'Bacground Bar Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-progressbar.bar-style.style-01 .barfiller .tip' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-progressbar.bar-style.style-01 .barfiller .tip:after' => 'border-color: {{VALUE}}',
                ],
                'default'   => '#ff5a5f',
            ]
        );

        $this->add_control(
            'percentage_color',
            [
                'label' => __( 'Percentage Text Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .barfiller .tip' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-progressbar.style-01 .progress-bar div span' => 'color: {{VALUE}}',
                ],
                'default'   => '#000',
            ]
        );

		$this->end_controls_section();


	}

	protected function render() {

        $settings = $this->get_settings();
            $progressbarId = uniqid();
        if( $settings['progressbar_style'] == 'style-one' ) {
        ?>
        <div class="eleddon-single-progressbar circular-style style-01">
            <div class="progress-bar" data-percent="<?php echo esc_attr( $settings['percentage'] ); ?>" data-duration="<?php echo esc_attr( $settings['speed'] ); ?>" data-color="#d6d6d6,<?php echo esc_attr( $settings['bg_bar_color'] ); ?>">
            </div>
            <h4><?php echo esc_html( $settings['title'] ); ?></h4>
        </div>
        <?php }else{ ?>
            <div class="eleddon-single-progressbar bar-style style-01">
                <h4><?php echo esc_html( $settings['title'] ); ?></h4>
                <div class="bar-wrapper">
                    <div id="bar<?php echo esc_attr( $progressbarId  ); ?>" class="barfiller" data-bgColor="<?php echo esc_attr( $settings['bg_bar_color'] ); ?>" data-duration="<?php echo esc_attr( $settings['speed'] ); ?>">
                        <div class="tipWrap">
                            <span class="tip"></span>
                        </div>
                        <span class="fill" data-percentage="<?php echo esc_attr( $settings['percentage'] ); ?>"></span>
                    </div>
                </div>
            </div>
        <?php   }   

    }
	
    public function get_script_depends() {
        return [ 'eleddon-main'];
    }


}
