<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor Service widget.
 *
 * @since 1.0
 */
class Service extends Widget_Base {

	public function get_name() {
		return 'eleddon-service';
	}

	public function get_title() {
		return __( 'Service', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-welcome';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();

        $assetsUrl = ELEDDON_WIDGET_ASSETS_URL.'img/service/';

        // ----------------------------------------  Service content ------------------------------
        $this->start_controls_section(
            'eleddon_service_settings',
            [
                'label' => esc_html__( 'Service', 'eleddon' ),
            ]
        );
        $this->add_control(
            'service_style',
            [
                'label' => __( 'Select Style', 'eleddon' ),
                'type' => 'popup-select',
                'label_block' => false,
                'options' => [
                    'style-one' => [
                        'name' => esc_html__( 'Service 1', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'service1.png', 
                        'type' => 'free' 
                    ],
                    'style-two' => [
                        'name' => esc_html__( 'Service 2', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'service2.png', 
                        'type' => 'free' 
                    ],                    
                    'style-three' => [
                        'name' => esc_html__( 'Service 3', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'service3.png', 
                        'type' => 'free' 
                    ],                    
                    'style-four' => [
                        'name' => esc_html__( 'Service 4', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'service4.png', 
                        'type' => 'free' 
                    ],                    

                ],
                'default' => 'style-one'
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Title', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Private Transport' , 'eleddon' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'content', [
                'label' => __( 'Content', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'icon', [
                'label' => esc_html__( 'Service Icon', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'fa fa-address-book-o'
            ]
        );

        $this->add_control(
            'btn-txt', [
                'label' => esc_html__( 'Read More Text', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Read More', 'eleddon' ),
                'condition' => [
                    'service_style' =>[ 'style-one', 'style-two','style-three' ],
                    ],
            ]
        );


        $this->add_control(
            'url', [
                'label' => esc_html__( 'Service Url', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'default'     => [
                        'url' => '#'
                    ],
            ]
        );

        $this->end_controls_section(); // End Service content


		//------------------------------ Service Style ------------------------------
		$this->start_controls_section(
			'eleddon_primary_color', [
				'label' => esc_html__( 'Primary Color', 'eleddon' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'primary_color',
            [
                'label' => __( 'Pick Primary Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-service .icon-box, 
                    .eleddon-single-service .readmore-btn .fa-arrow-right' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-service .service-title:after' => 'background-color: {{VALUE}}',
                ],
                'default'   => '#ff5a5f',
            ]
        );

		$this->end_controls_section();  

        /*
        * title style 
        */

        $this->start_controls_section(
            'eleddon_title_style', [
                'label' => esc_html__( 'Title Style', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Title Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-service .service-title' => 'color: {{VALUE}}',
                ],
                'default'   => '#28375A',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __( 'Title Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .service-title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->end_controls_section();

        /*
        * content style 
        */

        $this->start_controls_section(
            'eleddon_content_style', [
                'label' => esc_html__( 'Content Style', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'content_color',
            [
                'label' => __( 'Content Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}}  p' => 'color: {{VALUE}}',
                ],
                'default'   => '#28375a',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' => __( 'Content Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .eleddon-single-service p',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

     $this->end_controls_section();

        /*
        * read more style 
        */

        $this->start_controls_section(
            'eleddon_readmore_style', [
                'label' => esc_html__( 'Read More Style', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'readmore_color',
            [
                'label' => __( 'Read More Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-service .readmore-btn' => 'color: {{VALUE}}',
                ],
                'default'   => '#484848',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'readmore_typography',
                'label' => __( 'Content Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .eleddon-single-service .readmore-btn',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

     $this->end_controls_section();


        /*
        *  style four
        */

        $this->start_controls_section(
            'eleddon_style_four', [
                'label' => esc_html__( 'Style Four', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'style_four_txtcolor',
            [
                'label' => __( 'Style Four Hover Text Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-service.style-four:hover .content-box p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-service.style-four:hover i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .eleddon-single-service.style-four:hover h3.service-title' => 'color: {{VALUE}}',
                ],
                'default'   => '#fff',
            ]
        );

        $this->add_control(
            'style_four_bgcolor',
            [
                'label' => __( 'Style Four Hover Bg Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-service.style-four:hover' => 'background-color: {{VALUE}}',
                ],
                'default'   => '#cc0000',
            ]
        );


     $this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings();

        $service_style = $settings['service_style'];
        if( $service_style == 'style-one' || $service_style == 'style-two'  ) {
        ?>
        
        <div class="eleddon-single-service <?php echo esc_attr( $settings['service_style'] ); ?>">
            <div class="icon-box">
                <i class="<?php echo esc_attr( $settings['icon'] ); ?>"></i>
            </div>
            <h3 class="service-title"><?php echo esc_html( $settings['title'] ); ?></h3>
            <p><?php echo esc_html( $settings['content'] ); ?></p>
            <?php if( !empty( $settings['btn-txt' ] ) ) : ?>
                 <a href="<?php echo esc_url( $settings['url']['url'] ); ?>" class="readmore-btn"><?php echo esc_html( $settings['btn-txt' ] ); ?><i class="fas fa-arrow-right"></i></a>
            <?php endif; ?>
        </div>
        <?php }elseif( $service_style == 'style-three' ){ ?>
            <div class="eleddon-single-service style-three">
                <div class="icon-box">
                    <i class="<?php echo esc_attr( $settings['icon'] ); ?>"></i>
                </div>
                <div class="content-box">
                    <h3 class="service-title"><?php echo esc_html( $settings['title'] ); ?></h3>
                    <p><?php echo esc_html( $settings['content'] ); ?></p>
                    <a href="<?php echo esc_url( $settings['url']['url'] ); ?>" class="readmore-btn"><?php echo esc_html( $settings['btn-txt' ] ); ?></a>

                </div>
            </div>
        <?php }elseif( $service_style == 'style-four' ){  ?>

            <div class="eleddon-single-service style-four">
                <div class="heading-readmore-wrapper">
                    <div class="icon-heading-wrapper">
                        <div class="icon-box">
                            <i class="<?php echo esc_attr( $settings['icon'] ); ?>"></i>
                        </div>
                        <h3 class="service-title"><?php echo esc_html( $settings['title'] ); ?></h3>
                    </div>
                    <a href="<?php echo esc_url( $settings['url']['url'] ); ?>" class="readmore-btn"><i class="fas fa-arrow-right"></i></a>
                </div>
                <div class="content-box">
                    <p><?php echo esc_html( $settings['content'] ); ?></p>
                </div>
            </div>

        <?php }  ?>




        <?php

    }
	
    public function get_script_depends() {
        return [ 'eleddon-main'];
    }

     public function get_style_depends() {
        return [ 'fontawesome'];
    }


}
