<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor slider widget.
 *
 * @since 1.0
 */
class Slider extends Widget_Base {

	public function get_name() {
		return 'eleddon-slider';
	}

	public function get_title() {
		return __( 'Slider', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-post-slider';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

        $assetsUrl = ELEDDON_WIDGET_ASSETS_URL.'img/slider/';

        // ----------------------------------------  Slider content ------------------------------
        $this->start_controls_section(
            'eleddon_slider_settings',
            [
                'label' => esc_html__( 'Slider', 'eleddon' ),
            ]
        );


        $slider_repeater = new \Elementor\Repeater();

        $slider_repeater->add_control(
            'slider_title', [
                'label' => esc_html__( 'Slider Title', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'Explore The World With Us' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $slider_repeater->add_control(
            'slider_content', [
                'label' => esc_html__( 'Slider Content', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'Iceland, a Nordic island nation, is defined by its dramatic landscape with volcanoes,
                                        geysers, hot springs and lava fields.' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $slider_repeater->add_control(
            'youtube_video_id', [
                'label' => esc_html__( 'Youtube Video Id', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'ZpUO2mYtbLU',
                'desctipton' => esc_html__( 'keep blank to hide ' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $slider_repeater->add_control(
            'youtube_video_txt', [
                'label' => esc_html__( 'Youtube Video Text', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'WATCHING VIDEO', 'eleddon' ),
                'desctipton' => esc_html__( 'keep blank to hide ' , 'eleddon' ),
                'label_block' => true,
            ]
        );


        $slider_repeater->add_control(
            'slider_img', [
                'label' => esc_html__( 'Slider Image', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );

        $slider_repeater->add_control(
            'slider_btn_txt', [
                'label' => esc_html__( 'Slider Button Text', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                 'default' => esc_html__( 'Explore' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $slider_repeater->add_control(
            'slider_btn_url', [
                'label' => esc_html__( 'Slider Button Url', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'default'     => [
                        'url' => '#'
                    ],
            ]
        );

        $this->add_control(
            'sliders',
            [
                'label' => esc_html__( 'Slider', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $slider_repeater->get_controls(),
                'default' => [
                    [
                        'slider_title' => __( 'Explore The World With Us', 'eleddon' ),
                        'slider_content' => __( 'Iceland, a Nordic island nation, is defined by its dramatic landscape with volcanoes,
                                        geysers, hot springs and lava fields.', 'eleddon' ),
                        'youtube_video_id' => __( 'ZpUO2mYtbLU', 'eleddon' ),
                        'slider_btn_txt' => __( 'Explore', 'eleddon' ),
                    ],                    

                ],
                'title_field' => '{{{ slider_title }}}',
            ]
        );

        $this->add_control(
            'display_social_icon',
            [
                'label'     => esc_html__( 'Dispaly Social Icon ?', 'eleddon' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Yes', 'eleddon' ),
                'label_off' => esc_html__( 'No', 'eleddon' ),
                'return_value' => 'yes',
                'default' => 'yes',
    
            ]
        );

        $this->add_control(
            'display_arrow',
            [
                'label'     => esc_html__( 'Dispaly Arrow ?', 'eleddon' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Yes', 'eleddon' ),
                'label_off' => esc_html__( 'No', 'eleddon' ),
                'return_value' => 'yes',
                'default' => 'yes',
    
            ]
        );

        $this->add_control(
            'display_dots',
            [
                'label'     => esc_html__( 'Dispaly Dots ?', 'eleddon' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Yes', 'eleddon' ),
                'label_off' => esc_html__( 'No', 'eleddon' ),
                'return_value' => 'yes',
                'default' => 'yes',
    
            ]
        );

        $this->end_controls_section(); // End Slider content

        $this->start_controls_section(
            'eleddon_social',
            [
                'label' => esc_html__( 'Social Section', 'eleddon' ),
                'condition' => [
                    'display_social_icon' =>[ 'yes' ],
                ],
            ]
        );

        $repeater = new \Elementor\Repeater(); //scoial reapeter


        $this->add_control(
            'social_title', [
                'label' => esc_html__( 'Title', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                 'default' => esc_html__( 'FOLLOW US' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'social_icon', [
                'label' => esc_html__( 'Social Icon', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::ICON,
                 'default' => 'fa fa-facebook',
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'social_url', [
                'label' => esc_html__( 'Url', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'default'     => [
                        'url' => '#'
                    ],
            ]
        );

        $this->add_control(
            'social_icons',
            [
                'label' => esc_html__( 'Social Icon', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'social_icon' =>  'fa fa-facebook',
                        'social_url' =>  '#',
                    ],
                    [
                        'social_icon' =>  'fa fa-twitter',
                        'social_url' =>  '#',
                    ],                    

                ],
                'title_field' => '{{{ social_icon }}}',
            ]
        );


        $this->end_controls_section(); // End Slider content

	}

	protected function render() {

        $settings = $this->get_settings();
        ?>

            <!-- banner start -->
            <div class="hero-area style-01">
                <div class="hero-slider-wrapper slider-style-1">
                    <?php foreach ($settings['sliders'] as $slider ) : ?>
                    <div class="hero-slider-item " style="background-image: url( <?php echo esc_url( $slider['slider_img']['url'] ); ?> );">
                        <div class="eleddon-container">
                            <div class="eleddon-row">
                                <div class="eleddon-col-lg-9 eleddon-col-md-10">
                                    <div class="hero-content">
                                        <div class="content-wrapper">
                                            <?php if( ! empty( $slider[ 'slider_title' ] ) ) : ?>
                                                <h1><?php echo esc_html( $slider[ 'slider_title' ] ); ?></h1>
                                            <?php endif; ?>

                                            <p><?php echo esc_html( $slider[ 'slider_content' ] ); ?></p>

                                            <?php if( !empty( $slider['slider_btn_txt'] ) ) : ?>
                                                <a href="<?php echo esc_url( $slider[ 'slider_btn_url' ][ 'url' ] ); ?>" class="tbandel-btn"><?php echo esc_html( $slider['slider_btn_txt'] ); ?> </a>
                                            <?php endif; ?>

                                        </div>
                                        <?php if( !empty( $slider[ 'youtube_video_id' ] ) ) : ?>
                                            <div class="video-play-btn">
                                                <a href="https://www.youtube.com/watch?v=<?php echo esc_attr( $slider[ 'youtube_video_id' ] ); ?>" class="play-btn"><i class="fas fa-play"></i></a>
                                                <?php if( !empty( $slider[ 'youtube_video_txt' ] ) ) : ?>
                                                     <p><?php echo esc_html( $slider[ 'youtube_video_txt' ] ); ?></p>
                                                <?php endif ?>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php endforeach; ?>
                </div>
                
                    <div class="arrow-social-wrapper">
                        <div class="eleddon-container">
                            <div class="eleddon-row">
                                <?php if( $settings[ 'display_arrow' ] == 'yes' ) : ?>
                                    <div class="arrow-container"></div>
                                <?php endif; ?>
                                <?php if( $settings[ 'display_social_icon' ] == 'yes' ) : ?>
                                <div class="hero-social-container">
                                    <?php if( !empty( $settings[ 'social_title' ] ) ) : ?>
                                        <p><?php echo esc_html( $settings['social_title'] ); ?></p>
                                    <?php endif; ?>
                                    <ul class="social-wrapper">
                                        <?php foreach( $settings[ 'social_icons' ] as $icon ) : ?>
                                            <li>
                                                <a href="<?php echo esc_url( $icon[ 'social_url' ][ 'url' ] ); ?>"><i class="<?php echo esc_attr( $icon[ 'social_icon' ] ); ?>"></i></a>
                                            </li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                
                <?php if( $settings[ 'display_dots' ] == 'yes' ) : ?>
                    <div class="dot-container-wrapper">
                        <div class="eleddon-container">
                            <div class="eleddon-row">
                                <div class="dot-container"></div>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>

            </div>
            <!-- banner end -->

        <?php

    }
	
    public function get_script_depends() {
        return [ 'eleddon-main', 'slick', 'magnific-popup'];
    }
    public function get_style_depends() {
        return [ 'slick','magnific-popup'];
    }


}
