<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor Team widget.
 *
 * @since 1.0
 */
class Team extends Widget_Base {

	public function get_name() {
		return 'eleddon-team';
	}

	public function get_title() {
		return __( 'Team', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-person';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();

        $assetsUrl = ELEDDON_WIDGET_ASSETS_URL.'img/team/';

        // ----------------------------------------  Team content ------------------------------
        $this->start_controls_section(
            'eleddon_team_settings',
            [
                'label' => esc_html__( 'Team', 'eleddon' ),
            ]
        );
        $this->add_control(
            'team_style',
            [
                'label' => __( 'Select Style', 'eleddon' ),
                'type' => 'popup-select',
                'label_block' => false,
                'options' => [
                    'style-one' => [
                        'name' => esc_html__( 'Team 1', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'team1.png', 
                        'type' => 'free' 
                    ],
                    'style-two' => [
                        'name' => esc_html__( 'Team 2', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'team2.png', 
                        'type' => 'free' 
                    ],                    
                    'style-three' => [
                        'name' => esc_html__( 'Team 3', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'team3.png', 
                        'type' => 'free' 
                    ],                    
                    'style-four' => [
                        'name' => esc_html__( 'Team 4', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'team4.png', 
                        'type' => 'free' 
                    ],                    
                    'style-five' => [
                        'name' => esc_html__( 'Team 5', 'eleddon' ), 
                        'cat' => 'travel', 
                        'url' => $assetsUrl.'team5.png', 
                        'type' => 'free' 
                    ],

                ]
            ]
        );

        $this->add_control(
            'team_name', [
                'label' => __( 'Name', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Randy Meyer' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_designation', [
                'label' => __( 'Designation', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => __( 'Founder, CEO' , 'eleddon' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'team_img', [
                'label' => esc_html__( 'Member Image', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'icon', [
                'label' => esc_html__( 'Social Icon', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::ICON,
                'default' => esc_html__( 'fa fa-facebook' , 'eleddon' ),
                'label_block' => true,

            ]
        );

        $repeater->add_control(
            'url', [
                'label' => esc_html__( 'Social Url', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'default'     => [
                        'url' => '#'
                    ],
            ]
        );

        $this->add_control(
            'display_social_icon',
            [
                'label'     => esc_html__( 'Dispaly Social Icon', 'eleddon' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Yes', 'eleddon' ),
                'label_off' => esc_html__( 'No', 'eleddon' ),
                'return_value' => 'yes',
                'default' => 'yes',
    
            ]
        );

        $this->add_control(
            'list',
            [
                'label' => __( 'Social List', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'icon' => __( 'fa fa-facebook', 'eleddon' ),
                        'url' => __( '#', 'eleddon' ),
                    ],
                    [
                        'icon' => __( 'fa fa-twitter', 'eleddon' ),
                        'url' => __( '#', 'eleddon' ),
                    ],
                ],
                'title_field' => '{{{ icon }}}',
                'condition' => [
                    'display_social_icon' =>[ 'yes' ],
                ],
            ]

        );

        $this->add_control(
            'prourl', [
                'label' => esc_html__( 'Profilie Url', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::URL,
                'label_block' => true,
                'descripton'  => esc_html__( 'Leave Blank To Hide Icon', 'eleddon' ),
                'default'     => [
                        'url' => '#'
                    ],
                'condition' => [
                    'team_style' =>[ 'style-five' ],
                ],
            ]
        );


        $this->end_controls_section(); // End Team content


		//------------------------------ Team Style ------------------------------
        //name
        $this->start_controls_section(
            'team_name_settings', [
                'label' => esc_html__( 'Name ', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'name_color',
            [
                'label' => __( 'Name Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .name' => 'color: {{VALUE}}',
                ],
                'default'   => '#28375A',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'label' => __( 'Name Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .name',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

		$this->end_controls_section();

        //designation
        $this->start_controls_section(
            'team_designation_settings', [
                'label' => esc_html__( 'Designation ', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'designation_color',
            [
                'label' => __( 'Designation Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-team .post' => 'color: {{VALUE}}',
                ],
                'default'   => '#767676',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'designation_typography',
                'label' => __( 'Designation Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .eleddon-single-team .post',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->end_controls_section();


        //social style
        $this->start_controls_section(
            'team_social_settings', [
                'label' => esc_html__( 'Social Icon ', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => __( 'Social Icon Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-team .team-social li a' => 'color: {{VALUE}}',
                ],
                'default'   => '#484848',
            ]
        );

        $this->add_control(
            'icon_hover_color',
            [
                'label' => __( 'Social Icon Hover Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-team .team-social li a:hover' => 'color: {{VALUE}}',
                ],
                'default'   => '#ff5a5f',
            ]
        );

        $this->end_controls_section();


        //Others
        $this->start_controls_section(
            'othres_settings', [
                'label' => esc_html__( 'Others', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,

            ]
        );

        $this->add_control(
            'style_three_bg',
            [
                'label' => __( 'Background Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-team.style-three' => 'background-color: {{VALUE}}',
                ],
                'default'   => '#333',
                'condition' => [
                    'team_style' =>[ 'style-three' ],
                ],
            ]
        );    

        $this->add_control(
            'style_three_social_bg',
            [
                'label' => __( 'Background Social Icon', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-team.style-three .team-social' => 'background-color: {{VALUE}}',
                ],
                'default'   => '#CC0000',
                'condition' => [
                    'team_style' =>[ 'style-three' ],
                ],
            ]
        );        

        $this->add_control(
            'style_five_bg',
            [
                'label' => __( 'Background Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-team.style-five' => 'background-color: {{VALUE}}',
                ],
                'default'   => '#EDEFED',
                'condition' => [
                    'team_style' =>[ 'style-five' ],
                ],
            ]
        );       

        $this->add_control(
            'style_five_bg_url',
            [
                'label' => __( 'URL Background Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-single-team.style-five .readmore-btn' => 'background-color: {{VALUE}}',
                ],
                'default'   => '#CC0000',
                'condition' => [
                    'team_style' =>[ 'style-five' ],
                ],
            ]
        );

        $this->end_controls_section();



	}

	protected function render() {

        $settings = $this->get_settings();

        ?>
        <div class="eleddon-single-team <?php echo esc_attr( $settings['team_style']  ); ?>">
             <?php if( !empty( $settings['team_img']['url'] ) ) {
                $url = $settings['team_img']['url'];
              ?>
                <img src="<?php echo esc_url( $url ); ?>" alt="<?php echo esc_attr( eleddon_image_alt( $url ) ); ?>" class="thumbnail">
            <?php } ?>
            <h4 class="name"><?php echo esc_html( $settings['team_name'] ); ?></h4>
            <p class="post"><?php echo esc_html( $settings['team_designation'] ); ?></p>
            <?php if( $settings['display_social_icon'] == 'yes'  ): ?>
                <ul class="team-social">
                    <?php foreach( $settings['list'] as $list ) : ?>
                        <li><a href="<?php echo esc_url( $list['url']['url'] ); ?>"><i class="<?php echo esc_attr( $list['icon'] ); ?>"></i></a></li>
                    <?php endforeach; ?>
                </ul>
            <?php endif; ?>
            <?php if( $settings['team_style'] == 'style-five' && !empty( $settings['prourl']['url'] ) ) : ?>
                <a href="<?php echo esc_url( $settings['prourl']['url'] ); ?>" class="readmore-btn"><i class="fas fa-arrow-right"></i></a>
            <?php endif; ?>
        </div>
        <?php


    }
	
    public function get_script_depends() {
        return [ 'eleddon-main'];
    }


}
