<?php
namespace Eleddon\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Eleddon elementor testimonial widget.
 *
 * @since 1.0
 */
class Testimonial extends Widget_Base {

	public function get_name() {
		return 'eleddon-testimonial';
	}

	public function get_title() {
		return __( 'Testimonial', 'eleddon' );
	}

	public function get_icon() {
		return 'eicon-testimonial';
	}

	public function get_categories() {
		return ['eleddon-elements-category'];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();

        $assetsUrl = ELEDDON_WIDGET_ASSETS_URL.'img/testimonial/';

        // ----------------------------------------  Testimonial content ------------------------------
        $this->start_controls_section(
            'eleddon_testimonial_settings',
            [
                'label' => esc_html__( 'Testimonial', 'eleddon' ),
            ]
        );

        $this->add_control(
            'testimonial_style',
            [
                'label' => __( 'Select Style', 'eleddon' ),
                'type' => 'popup-select',
                'label_block' => false,
                'options' => [
                    'test-style-01' => [
                        'name' => esc_html__( 'Testimonial 1', 'eleddon' ), 
                        'cat' => 'Travel', 
                        'url' => $assetsUrl.'testimonial1.png', 
                        'type' => 'free' 
                    ],
                    'test-style-02' => [
                        'name' => esc_html__( 'Testimonial 2', 'eleddon' ), 
                        'cat' => 'Travel', 
                        'url' => $assetsUrl.'testimonial2.png', 
                        'type' => 'free' 
                    ]

                ],
                'default' => 'test-style-01'
            ]
        );
        $repeater->add_control(
            'testimonial_name', [
                'label' => esc_html__( 'Name', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'List Title' , 'eleddon' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'testimonial_designation', [
                'label' => esc_html__( 'Designation', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'List Title' , 'eleddon' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'testimonial_desc', [
                'label' => esc_html__( 'Review Comment', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__( 'List Title' , 'eleddon' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'testimonial_img', [
                'label' => esc_html__( 'Picture', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'testimonial',
            [
                'label' => esc_html__( 'Testimonial', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'testimonial_name' => __( 'Randy Meyer', 'eleddon' ),
                        'testimonial_designation' => __( 'Torist', 'eleddon' ),
                        'testimonial_desc' => __( 'Duis porta, ligula rhoncus euismod pretium, nisi tellus eleifend odio, luctus viverra sem dolor id sem', 'eleddon' ),
                    ],
                    [
                        'testimonial_name' => __( 'Randy Meyer', 'eleddon' ),
                        'testimonial_designation' => __( 'Torist', 'eleddon' ),
                        'testimonial_desc' => __( 'Duis porta, ligula rhoncus euismod pretium, nisi tellus eleifend odio, luctus viverra sem dolor id sem', 'eleddon' ),
                    ],
                    [
                        'testimonial_name' => __( 'Randy Meyer', 'eleddon' ),
                        'testimonial_designation' => __( 'Torist', 'eleddon' ),
                        'testimonial_desc' => __( 'Duis porta, ligula rhoncus euismod pretium, nisi tellus eleifend odio, luctus viverra sem dolor id sem', 'eleddon' ),
                    ],
                    [
                        'testimonial_name' => __( 'Randy Meyer', 'eleddon' ),
                        'testimonial_designation' => __( 'Torist', 'eleddon' ),
                        'testimonial_desc' => __( 'Duis porta, ligula rhoncus euismod pretium, nisi tellus eleifend odio, luctus viverra sem dolor id sem', 'eleddon' ),
                    ],
                    [
                        'testimonial_name' => __( 'Randy Meyer', 'eleddon' ),
                        'testimonial_designation' => __( 'Torist', 'eleddon' ),
                        'testimonial_desc' => __( 'Duis porta, ligula rhoncus euismod pretium, nisi tellus eleifend odio, luctus viverra sem dolor id sem', 'eleddon' ),
                    ],
                ],
                'title_field' => '{{{ testimonial_name }}}',
            ]
        );


        $this->end_controls_section(); // End Testimonial content

        /**
         * Style Tab
         * ------------------------------ Testimonial Settings ------------------------------
         *
         */
        $this->start_controls_section(
            'testimonial_settings', [
                'label' => esc_html__( 'Style Box', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        // Slider Settings

        $this->add_control(
            'testimonial_item',
            [
                'label' => esc_html__( 'items', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 3,
            ]
        );

        $this->add_control(
            'testimonial_loop',
            [
                'label'     => esc_html__( 'Loop', 'eleddon' ),
                'type'      => \Elementor\Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Yes', 'eleddon' ),
                'label_off' => esc_html__( 'No', 'eleddon' ),
                'return_value' => 'yes',
                'default' => 'yes',
    
            ]
        );

        $this->end_controls_section();
        /*
         * testimonial css style
        */
        $this->start_controls_section(
            'testimonial_name_settings', [
                'label' => esc_html__( 'Name ', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'name_color',
            [
                'label' => __( 'Name Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .author-name' => 'color: {{VALUE}}',
                ],
                'default'   => '#28375A',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'label' => __( 'Name Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .author-name',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->end_controls_section();

        //name style

        $this->start_controls_section(
                'testimonial_name_settings', [
                'label' => esc_html__( 'Name ', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'name_color',
            [
                'label' => __( 'Name Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .author-name' => 'color: {{VALUE}}',
                ],
                'default'   => '#28375A',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'label' => __( 'Name Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .author-name',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->end_controls_section();       

         //designation style

        $this->start_controls_section(
                'testimonial_designation_settings', [
                'label' => esc_html__( 'Designation ', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'designation_color',
            [
                'label' => __( 'Designation Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .author-title' => 'color: {{VALUE}}',
                ],
                'default'   => '#767676',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'designation_typography',
                'label' => __( 'Name Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .author-title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->end_controls_section();


         //testimonial content style

        $this->start_controls_section(
                'testimonial_content_settings', [
                'label' => esc_html__( 'Content ', 'eleddon' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'conent_color',
            [
                'label' => __( 'Content Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .test-content' => 'color: {{VALUE}}',
                ],
                'default'   => '#28375a',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'label' => __( 'Content Typography', 'eleddon' ),
                'selector' => '{{WRAPPER}} .test-content',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3
            ]
        );

        $this->add_control(
            'style_one_bg_color',
            [
                'label' => __( 'Background Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-testimonial-wrapper.test-style-01 .test-content' => 'background-color: {{VALUE}}',
                ],
                'default'   => '#f2f2f2',
                'condition' => [
                    'testimonial_style' =>[ 'test-style-01' ],
                ],
            ]
        );        

        $this->add_control(
            'style_two_bg_color',
            [
                'label' => __( 'Center Testimonial Background Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-testimonial-wrapper.test-style-02 .center .eleddon-testimonial-item' => 'background-color: {{VALUE}}',
                ],
                'default'   => '#ff5a5f',
                'condition' => [
                    'testimonial_style' =>[ 'test-style-02' ],
                ],
            ]
        );  

        $this->add_control(
            'style_two_text_color',
            [
                'label' => __( 'Center Testimonial Text Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-testimonial-wrapper.test-style-02 .center .eleddon-testimonial-item .author-name,
                    .eleddon-testimonial-wrapper.test-style-02 .center .eleddon-testimonial-item .author-title,  .eleddon-testimonial-wrapper.test-style-02 .center .eleddon-testimonial-item p' => 'color: {{VALUE}}',
                ],
                'default'   => '#fff',
                'condition' => [
                    'testimonial_style' =>[ 'test-style-02' ],
                ],
            ]
        );

         $this->add_control(
            'dot_color',
            [
                'label' => __( 'Dot Color', 'eleddon' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .eleddon-testimonial-wrapper .owl-dots .owl-dot' => 'background-color: {{VALUE}}',
                ],
                'default'   => '#ff5a5f',
            ]
        );
        
        $this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings();

        $dataOption = [ 'items' => $settings['testimonial_item'], 'loop' => $settings['testimonial_loop'], 'style'=>$settings['testimonial_style']  ];
        $dataOption = json_encode( $dataOption );
        if ( $settings['testimonial_style'] == 'test-style-01' ) {
        ?>
         <div class="eleddon-testimonial-wrapper test-style-01 owl-carousel" data-options="<?php echo esc_attr( $dataOption ); ?>">
            <?php
                if( !empty( $settings['testimonial'] ) ):
                    foreach( $settings['testimonial'] as $testimonial ):

            ?>
                <div class="eleddon-testimonial-item">
                    <div class="test-author">
                        <?php
                        if( !empty( $testimonial['testimonial_img']['url'] ) ) {

                            $url = $testimonial['testimonial_img']['url'];

                            echo '<img src="'.esc_url( $url ).'" alt="'.esc_attr( eleddon_image_alt( $url ) ).'" class="thumb">';
                        } 
                        //
                        if( !empty( $testimonial['testimonial_name'] ) ) {
                            echo '<h4 class="author-name">'.esc_html( $testimonial['testimonial_name'] ).'</h4>';
                        }
                        //
                        if( !empty( $testimonial['testimonial_designation'] ) ) {
                            echo '<p class="author-title">'.esc_html( $testimonial['testimonial_designation'] ).'</p>';
                        }
                        ?>
                    </div>

                    <div class="test-content">
                        <i class="fas fa-quote-right"></i>
                        <?php 
                            if( !empty( $testimonial['testimonial_desc'] ) ) {
                                echo '<p>'.esc_html( $testimonial['testimonial_desc'] ).'</p>';
                            }
                        ?>
                    </div>

                </div>
            <?php endforeach; endif; ?>
         </div>
        <?php
    }else{ ?>
        <div class="eleddon-testimonial-wrapper test-style-02 owl-carousel" data-options="<?php echo esc_attr( $dataOption ); ?>">
            <?php
                if( !empty( $settings['testimonial'] ) ):
                    foreach( $settings['testimonial'] as $testimonial ):

            ?>
            <div class="eleddon-testimonial-item">
                <div class="test-content">
                    <i class="fas fa-quote-left"></i>
                    <p><?php 
                            if( !empty( $testimonial['testimonial_desc'] ) ) {
                                echo '<p>'.esc_html( $testimonial['testimonial_desc'] ).'</p>';
                            }
                        ?>
                    </p>
                </div>
                <div class="test-author">
                    <?php
                        if( !empty( $testimonial['testimonial_img']['url'] ) ) {

                            $url = $testimonial['testimonial_img']['url'];

                            echo '<img src="'.esc_url( $url ).'" alt="'.esc_attr( eleddon_image_alt( $url ) ).'" class="thumb">';
                        } 
                        //
                        if( !empty( $testimonial['testimonial_name'] ) ) {
                            echo '<h4 class="author-name">'.esc_html( $testimonial['testimonial_name'] ).'</h4>';
                        }
                        //
                        if( !empty( $testimonial['testimonial_designation'] ) ) {
                            echo '<p class="author-title">'.esc_html( $testimonial['testimonial_designation'] ).'</p>';
                        }
                        ?>
                </div>
            </div>
             <?php endforeach; endif; ?>
        </div>
    <?php }

    }
	
    public function get_script_depends() {
        return [ 'eleddon-main', 'owl-carousel'];
    }
    public function get_style_depends() {
        return [ 'owl-carousel'];
    }


}
