<?php
namespace Eleddon\Widgets;
/**
 * Eleddon Widgets Base
 *
 * @package     Eleddon
 * @author      Codingeek
 * @copyright   2019 Codingeek
 * @license     GPL-2.0-or-later
 *
 *
 */


if( !defined( 'WPINC' ) ) {
    die;
}

if( !class_exists('Widgets_Base') ) {

class Widgets_Base {

	private static $instance = null;


	function __construct() {

		add_action( 'init', [ $this, 'init_hooks' ] );

		//add category
		add_action( 'elementor/elements/categories_registered', [ $this, 'registered_category'] );

	}

	//
	public static function getInstance() {

		if( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;

	}

	public function init_hooks() {

		// Register New Widgets
        add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );

	}


	//
	public function registered_category() {

        \Elementor\Plugin::instance()->elements_manager->add_category( 'eleddon-elements-category', [
            'title' => esc_html__( 'Eleddon', 'eleddon' ),
        ], 1 );

	}

    /**
     * Widgets Register 
     *
     *
     * @since 1.0.0
     *
     * @access public
     */

	public function register_widgets() {

		$widgets = new Widgets_List();

		$activeWidget = get_option( 'eleddon_widgets_activation' );

		foreach( $widgets->widgets_map() as $widget ) {

			if( !empty( $widget['name'] ) && in_array( $widget['name'], $activeWidget  ) ) {

				$widgetName = $widget['name'];

				$prepareName = $this->file_name_prepare( $widgetName );
				

				$file = ELEDDON_DIR_WIDGETS . 'all-widgets/'.$prepareName.'/'.$prepareName.'.php';


				if( is_readable( $file ) ) {

					require_once( $file );

					$prepareClassName = $this->class_name_prepare( $widgetName );

					$className = '\Eleddon\Widgets\\'.$prepareClassName;

					if( class_exists( $className ) ) {
						
						\Elementor\Plugin::instance()->widgets_manager->register_widget_type(  new $className );
					}

				}


			}
		}
	}

	/**
     * File name prepare
     * From widgets list
     *
     * @since 1.0.0
     *
     * @access public
     */
	public function file_name_prepare( $name ) {

		return str_replace( ['_', ' '], '-', $name );

	}
	/**
     * Class name prepare
     * From widgets list
     *
     * @since 1.0.0
     *
     * @access public
     */
	public function class_name_prepare( $name ) {

		return str_replace( ['-', ' '], '_',  $name );

	}

}

Widgets_Base::getInstance();

}